Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(567)

Unified Diff: chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.h

Issue 1724183005: Change ChooserBubbleDelegate class name to ChooserBubbleController (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: merged changes from master, resolved conflicts and updated related files Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.h
diff --git a/chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_delegate.h b/chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.h
similarity index 64%
rename from chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_delegate.h
rename to chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.h
index 26d2455f7fb124fac66c5796ed813c07c59e54b0..f619e13c2fbe0780ed14de8585a379529306cefc 100644
--- a/chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_delegate.h
+++ b/chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.h
@@ -2,27 +2,27 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_DELEGATE_H_
-#define CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_DELEGATE_H_
+#ifndef CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_CONTROLLER_H_
+#define CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_CONTROLLER_H_
#include <stddef.h>
#include "base/macros.h"
-#include "chrome/browser/ui/website_settings/chooser_bubble_delegate.h"
+#include "chrome/browser/ui/website_settings/chooser_bubble_controller.h"
#include "components/bubble/bubble_reference.h"
class BluetoothChooserDesktop;
// BluetoothChooserBubbleDelegate is a chooser that presents a list of
// Bluetooth device names, which come from |bluetooth_chooser_desktop_|.
// It can be used by WebBluetooth API to get the user's permission to
// access a Bluetooth device.
-class BluetoothChooserBubbleDelegate : public ChooserBubbleDelegate {
+class BluetoothChooserBubbleController : public ChooserBubbleController {
public:
- explicit BluetoothChooserBubbleDelegate(content::RenderFrameHost* owner);
- ~BluetoothChooserBubbleDelegate() override;
+ explicit BluetoothChooserBubbleController(content::RenderFrameHost* owner);
+ ~BluetoothChooserBubbleController() override;
- // ChooserBubbleDelegate:
+ // ChooserBubbleController:
size_t NumOptions() const override;
const base::string16& GetOption(size_t index) const override;
void Select(size_t index) override;
@@ -41,17 +41,17 @@ class BluetoothChooserBubbleDelegate : public ChooserBubbleDelegate {
bluetooth_chooser_ = bluetooth_chooser;
}
- void set_bubble_controller(BubbleReference bubble_controller) {
- bubble_controller_ = bubble_controller;
+ void set_bubble_reference(BubbleReference bubble_reference) {
+ bubble_reference_ = bubble_reference;
}
private:
// Each pair is a (device name, device id).
std::vector<std::pair<base::string16, std::string>> device_names_and_ids_;
BluetoothChooserDesktop* bluetooth_chooser_;
- BubbleReference bubble_controller_;
+ BubbleReference bubble_reference_;
- DISALLOW_COPY_AND_ASSIGN(BluetoothChooserBubbleDelegate);
+ DISALLOW_COPY_AND_ASSIGN(BluetoothChooserBubbleController);
};
-#endif // CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_DELEGATE_H_
+#endif // CHROME_BROWSER_UI_BLUETOOTH_BLUETOOTH_CHOOSER_BUBBLE_CONTROLLER_H_
« no previous file with comments | « no previous file | chrome/browser/ui/bluetooth/bluetooth_chooser_bubble_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,27 +2,27 @@
#include "components/bubble/bubble_reference.h"
class BluetoothChooserDesktop;
-// BluetoothChooserBubbleDelegate is a chooser that presents a list of
+// BluetoothChooserBubbleController is a chooser that presents a list of
// Bluetooth device names, which come from |bluetooth_chooser_desktop_|.
// It can be used by WebBluetooth API to get the user's permission to
This is Rietveld 408576698